![Build Status](https://github.com/dranjan/python-plyfile/actions/workflows/python-package.yml/badge.svg)

Welcome to the `plyfile` Python module, which provides a simple facility
for reading and writing ASCII and binary PLY files.

# Quick start

To install the latest official release:

    pip3 install plyfile

To install from source:

    # From the project root
    pip3 install .

# Quick links

## PLY format reference

[Link](https://web.archive.org/web/20161221115231/http://www.cs.virginia.edu/~gfx/Courses/2001/Advanced.spring.01/plylib/Ply.txt)

## Project documentation

[Link](https://python-plyfile.readthedocs.io)

## Getting help

Have questions? Feel free to ask in
[Discussions](https://github.com/dranjan/python-plyfile/discussions).

## Reporting bugs

[Issues](https://github.com/dranjan/python-plyfile/issues)

## Contributing

[Information for developers](https://python-plyfile.readthedocs.io/en/latest/developing.html)

# Copyright and license

Copyright Darsh Ranjan and `plyfile` authors.

This software is released under the terms of the GNU General Public
License, version 3.  See the file `COPYING` for details.
